@@ -9,7 +9,7 @@ from colorama import Fore
 
 def check_for_py_update():
     outdated_packages_str = os.popen("pip list -o --format json").read()
-    if outdated_packages_str != '[]':
+    if outdated_packages_str != '[]\n':
         return outdated_packages_str
     else:
         print(f"All packages are up to date [{Fore.GREEN}OK{Fore.RESET}]")
